@@ -4,7 +4,7 @@
  * Gnome Crystal
  * sizedlg.cc 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -27,10 +27,13 @@
 #include "document.h"
 #include "application.h"
 
-gcSizeDlg::gcSizeDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLADEDIR"/size.glade", "size")
+gcSizeDlg::gcSizeDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLADEDIR"/size.glade", "size", pDoc)
 {
+	if (!xml) {
+		delete this;
+		return;
+	}
 	m_pDoc = pDoc;
-	pDoc->NotifyDialog(this);
 	MinX = (GtkEntry*) glade_xml_get_widget(xml, "xmin");
 	MaxX = (GtkEntry*) glade_xml_get_widget(xml, "xmax");
 	MinY = (GtkEntry*) glade_xml_get_widget(xml, "ymin");
@@ -55,7 +58,6 @@ gcSizeDlg::gcSizeDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLADED
 
 gcSizeDlg::~gcSizeDlg()
 {
-	m_pDoc->RemoveDialog(this);
 }
 
 bool gcSizeDlg::Apply ()
@@ -86,6 +88,6 @@ bool gcSizeDlg::Apply ()
 	}
 	m_pDoc->SetSize (xmin, xmax, ymin, ymax, zmin, zmax);
 	m_pDoc->Update ();
-	m_pDoc->SetDirty ();
+	m_pDoc->SetDirty (true);
 	return true;
 }
